@@ -10,10 +10,14 @@
 /* .Call calls */
 extern SEXP _eseis_stalta_event_freeze(SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP _eseis_stalta_event_nofreeze(SEXP, SEXP, SEXP, SEXP);
+extern SEXP _eseis_kurtosis_event(SEXP, SEXP);
+extern SEXP _eseis_correlation_event(SEXP, SEXP);
 
 static const R_CallMethodDef CallEntries[] = {
     {"_eseis_stalta_event_freeze",   (DL_FUNC) &_eseis_stalta_event_freeze,   5},
     {"_eseis_stalta_event_nofreeze", (DL_FUNC) &_eseis_stalta_event_nofreeze, 4},
+    {"_eseis_kurtosis_event", (DL_FUNC) &_eseis_kurtosis_event, 2},
+    {"_eseis_correlation_event", (DL_FUNC) &_eseis_correlation_event, 2},
     {NULL, NULL, 0}
 };
 
